#clear the memory
rm (list=ls())

#load the learning set
library(xlsReadWrite)
setwd("D:/DataMining/Databases_for_mining/dataset_for_soft_dev_and_comparison/idt-spad")
pima.train <- read.xls(file="pima-storing-models.xls",colNames=T,sheet="apprentissage")

#induction of the decision tree using the rpart library
library(rpart)
tree.unpruned <- rpart(diabete ~ ., data = pima.train)
#specifying the right size of the tree by post-pruning
#plotcp(tree.unpruned)
tree.final <- prune(tree.unpruned,cp=0.04)
#printing the decision tree
print(tree.final)

#logistic regression with glm -- all the variables
logreg.initial <- glm(diabete ~ 1, data = pima.train, family = binomial)
#variable selection for logistic regression - forward search
library(MASS)
logreg.final <- stepAIC(logreg.initial, scope=list(lower="~1",upper="~age+pedigree+pregnant+bodymass+plasma"),trace=T,direction="forward")
#print the final model
print(logreg.final)

#forward selection for lda at 1% significance level with greedy.wilks
library(klaR)
selection.var <- greedy.wilks(diabete ~ ., data = pima.train, niveau = 0.01)
#lda with the selected variables
lda.final <- lda(selection.var$formula, data = pima.train)
#print the model
print(lda.final)

#PCA on the predictors
pca <- princomp(~age+pedigree+pregnant+bodymass+plasma, data = pima.train, cor = T, scores = T)
#lda on the 2 first factors
scores <- as.data.frame(pca$scores)
lda.pca <- lda(pima.train$diabete ~ scores$Comp.1 + scores$Comp.2)
print(lda.pca)

#delete the previous version of the file for models if it exists
file.remove("models.db")
#storing the models into "models.db" in the current directory
library(filehash)
dumpObjects(tree.final,dbName="models.db")
dumpObjects(logreg.final,dbName="models.db")
dumpObjects(lda.final,dbName="models.db")
dumpObjects(pca,dbName="models.db")
dumpObjects(lda.pca,dbName="models.db")
